#!/bin/sh
( echo 'you need to change: Driver       "nv"' )
( echo '                to: Driver       "nvidia"' )
( echo in your /etc/X11/xorg.conf )
( depmod -aq )
( cd usr/lib ; rm -rf libGL.so )
( cd usr/lib ; ln -sf libGL.so.1.0.8178 libGL.so )
